@@ -10,7 +10,7 @@
 #******************************************************************************************
 #******************************************************************************************
 
-lingpg <- function(Y, gender = NULL, id, weight=NULL, sort = NULL,
+lingpg <- function(Y, gender = NULL, id=NULL, weight=NULL, sort = NULL,
                    Dom = NULL, period=NULL, dataset = NULL,
                    var_name="lin_gpg") {
 
@@ -22,34 +22,26 @@ lingpg <- function(Y, gender = NULL, id, weight=NULL, sort = NULL,
    if (is.null(gender)) stop("'gender' must be supplied")
 
    if (!is.null(dataset)) {
-        dataset <- data.frame(dataset)
-        if (checker(Y, dataset, "Y")) Y <- dataset[, Y] 
-        if (checker(gender, dataset, "gender")) gender <- dataset[, gender]  
+        dataset <- data.table(dataset)
+        if (checker(Y, dataset, "Y")) Y <- dataset[, Y, with=FALSE] 
+        if (checker(gender, dataset, "gender")) gender <- dataset[, gender, with=FALSE]  
 
         if (!is.null(id)) {
-             id2 <- id
-             if (checker(id, dataset, "id")) id <- data.frame(dataset[, id], stringsAsFactors=FALSE)
-             names(id) <- id2 }
+              if (checker(id, dataset, "id")) id <- dataset[, id, with=FALSE] }
 
         if (!is.null(weight)) {
-             if (checker(weight, dataset, "weight")) weight <- dataset[, weight] }
+             if (checker(weight, dataset, "weight")) weight <- dataset[, weight, with=FALSE] }
 
         if(!is.null(sort)) {
-            if (checker(sort, dataset, "sort")) sort <- dataset[, sort] }
+            if (checker(sort, dataset, "sort")) sort <- dataset[, sort, with=FALSE] }
 
         if (!is.null(period)) {
-            aperiod <- period  
             if (min(period %in% names(dataset))!=1) stop("'period' does not exist in 'dataset'!")
-            if (min(period %in% names(dataset))==1) {
-                                period <- data.frame(dataset[, period], stringsAsFactors=FALSE)
-                                names(period) <- aperiod }}
+            if (min(period %in% names(dataset))==1) dataset[, period, with=FALSE] }
 
         if (!is.null(Dom)) {
-             Dom2 <- Dom
-             if (checker(Dom, dataset, "Dom")) {
-                     Dom <- as.data.frame(dataset[, Dom], stringsAsFactors=FALSE) 
-                     names(Dom) <- Dom2 }    }
-      }
+             if (checker(Dom, dataset, "Dom")) Dom <- dataset[, Dom, with=FALSE]}
+    }
 
    # check vectors
    # Y
@@ -61,8 +53,11 @@ lingpg <- function(Y, gender = NULL, id, weight=NULL, sort = NULL,
    if (any(is.na(Y))) stop("'Y' has unknown values")
 
    # gender
+   gender <- data.frame(gender)
+   if (nrow(gender) != n) stop("'gender' must be the same length as 'Y'")
+   if (ncol(gender) != 1) stop("'gender' must be vector or 1 column data.frame, matrix, data.table")
+   gender <- gender[,1]
    if (!is.numeric(gender)) stop("'gender' must be numerical")
-   if (length(gender) != n) stop("'gender' must be the same length as 'Y'")
    if (length(unique(gender)) != 2) stop("'gender' must be exactly two values")
    if (!all.equal(unique(gender),c(1, 2))) stop("'gender' must be value 1 for male, 2 for females")
  
@@ -76,18 +71,21 @@ lingpg <- function(Y, gender = NULL, id, weight=NULL, sort = NULL,
    if (any(is.na(weight))) stop("'weight' has unknown values")
  
    # sort
-   if (!is.null(sort) && !is.vector(sort) && !is.ordered(sort)) {
-         stop("'sort' must be a vector or ordered factor") }
-   if (!is.null(sort) && length(sort) != n) stop("'sort' must have the same length as 'Y'")     
-   
-   # period     
+   if (!is.null(sort)) {
+        sort <- data.frame(sort)
+        if (length(sort) != n) stop("'sort' must have the same length as 'Y'")
+        if (ncol(sort) != 1) stop("'sort' must be vector or 1 column data.frame, matrix, data.table")
+        sort <- sort[, 1]
+   }
+ 
+  # period     
    if (!is.null(period)) {
        period <- data.table(period)
        if (any(duplicated(names(period)))) 
                  stop("'period' are duplicate column names: ", 
                       paste(names(period)[duplicated(names(period))], collapse = ","))
        if (nrow(period) != n) stop("'period' must be the same length as 'Y'")
-       if(any(is.na(period))) stop("'period' has unknown values")  
+       if(any(is.na(period))) stop("'period' has unknown values")
    }
 
    # id
@@ -111,7 +109,7 @@ lingpg <- function(Y, gender = NULL, id, weight=NULL, sort = NULL,
                       paste(names(Dom)[duplicated(names(Dom))], collapse = ","))
              if (is.null(names(Dom))) stop("'Dom' must be colnames")
              if (nrow(Dom) != n) stop("'Dom' must be the same length as 'Y'")
-             Dom <- Dom[, lapply(.SD, as.character), .SDcols = names(Dom)]
+             Dom[, (names(Dom)):=lapply(.SD, as.character)]
        }
 
 
